# ruff: noqa: E501
# Generated by Django 6.0 on 2025-12-19 17:56

from django.db import migrations, models

import django_hawkeye.indexes


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Article",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("content", models.TextField()),
                ("author", models.CharField(max_length=100)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
            ],
            options={
                "indexes": [
                    django_hawkeye.indexes.BM25Index(
                        fields=["content"], name="article_content_bm25"
                    )
                ],
            },
        ),
    ]
